import { __decorate } from "tslib";
import { Component } from '@angular/core';
import { FormControl, Validators } from '@angular/forms';
import { AppComponentClass } from 'src/app/shared/service/AppComponent.class';
let AddagentComponent = class AddagentComponent extends AppComponentClass {
    constructor(data, inboundService, router, fb, route) {
        super(data, router, fb);
        this.data = data;
        this.inboundService = inboundService;
        this.router = router;
        this.fb = fb;
        this.route = route;
        this.submitted = false;
        this.responseMessage = "";
        this.navigationExtras = {};
        this.errMessage = "";
        this.dids = [];
        this.strategy = {};
        this.selectedItems = [];
        this.closeDropdownSelection = true;
        this.titleText = '';
        this.saveButton = 'Submit';
        this.route.paramMap.subscribe((params) => {
            this.groupKey = params.get('id');
            this.Urldata = this.router.url.split("/")[2];
            if (this.Urldata == 'edit-agent') {
                this.titleText = "Edit Agent",
                    this.saveButton = 'Update';
            }
            else {
                this.titleText = "Add Agent",
                    this.saveButton = 'Submit';
            }
        });
    }
    ngOnInit() {
        this.addagentForm = this.fb.group({
            IdAgent: [''],
            FullName: ['', [Validators.required, Validators.pattern("^[a-zA-Z \'][a-zA-Z \']*$")]],
            UserName: ['', [Validators.required, Validators.pattern(/^([A-z0-9!@#$%^&*().,<>{}[\]<>?_`~=+\-|;:\'\"\/])*[^\s]\1*$/)]],
            CallerId: ['', [Validators.required]],
            Password: ['', [Validators.required, Validators.minLength(5)]],
            Group: [this.groupKey],
            VmPin: ['', [Validators.required, Validators.minLength(4), Validators.maxLength(4), Validators.pattern("[0-9]+")]]
        });
        this.filterForm = this.fb.group({
            // fromDate: new FormControl(this.startDate()),
            // toDate: new FormControl(this.current_datetime()),
            selectedUser: new FormControl(''),
            didnumber: new FormControl('', [Validators.minLength(3), Validators.maxLength(10)]),
            didnpa: new FormControl('', [Validators.minLength(3)]),
            selectState: new FormControl(''),
            selectSMS: new FormControl('')
        });
        this.strategy = {
            singleSelection: true,
            idField: 'did',
            textField: 'did',
            itemsShowLimit: 3,
            allowSearchFilter: true,
            closeDropDownOnSelection: this.closeDropdownSelection
        };
        this.dids = [];
        this.inboundService.onGetBuyDids(this.filterForm.value).subscribe(res => {
            this.dids = res.data;
        }, err => {
            this.responseMessage = err.message;
            setTimeout(() => {
                this.responseMessage = "";
            }, 5000);
        });
        this.route.paramMap.subscribe((params) => {
            this.id = params.get('id');
            if (this.id) {
                this.data.getSingleAgent(this.id).subscribe(result => {
                    if (result.status == 200) {
                        this.agent = result.data[0];
                        this.addagentForm.patchValue({
                            IdAgent: this.agent.idagent,
                            FullName: this.agent.full_name,
                            UserName: this.agent.username,
                            Password: this.agent.password,
                            Group: this.agent.group,
                            VmPin: this.agent.vm_pin
                        });
                        this.selectedItems = [this.agent.callerid];
                    }
                    else {
                        this.errMessage = result.message;
                        setTimeout(() => {
                            this.errMessage = "";
                        }, 5000);
                    }
                });
            }
        });
    }
    getCallerId(event) {
        this.addagentForm.patchValue({
            Strategy: event.did
        });
        this.selectedItems = [event.did];
    }
    // @to save/update form data
    onSubmit() {
        this.submitted = true;
        if (this.addagentForm.invalid) {
            return;
        }
        else {
            // this.addagentForm.patchValue({
            //   CallerId: this.addagentForm.value.CallerId[0].did
            // });
            if (this.addagentForm.value.IdAgent == undefined || this.addagentForm.value.IdAgent == '') {
                this.data.saveAgent(this.addagentForm.value).subscribe(res => {
                    if (res.status == 201) {
                        this.responseMessage = res.message;
                        setTimeout(() => {
                            this.responseMessage = "";
                        }, 5000);
                        this.router.navigateByUrl('/agents/agent-details/' + this.groupKey);
                    }
                    else {
                        this.errMessage = res.message;
                        setTimeout(() => {
                            this.errMessage = "";
                        }, 5000);
                    }
                }, err => {
                    this.responseMessage = err.message;
                    setTimeout(() => {
                        this.responseMessage = "";
                    }, 5000);
                });
            }
            else {
                this.data.updateAgent(this.addagentForm.value).subscribe(res => {
                    if (res.status == 201) {
                        this.responseMessage = res.message;
                        setTimeout(() => {
                            this.responseMessage = "";
                        }, 5000);
                        this.router.navigateByUrl('/agents/agent-details/' + this.agent.group);
                    }
                    else {
                        this.errMessage = res.message;
                        setTimeout(() => {
                            this.errMessage = "";
                        }, 5000);
                    }
                }, err => {
                    this.responseMessage = err.message;
                    setTimeout(() => {
                        this.responseMessage = "";
                    }, 5000);
                });
            }
        }
    }
    onReset() {
        this.submitted = false;
        this.addagentForm.reset();
    }
};
AddagentComponent = __decorate([
    Component({
        selector: 'app-addagent',
        templateUrl: './addagent.component.html',
        styleUrls: ['./addagent.component.css']
    })
], AddagentComponent);
export { AddagentComponent };
//# sourceMappingURL=addagent.component.js.map