import { __decorate } from "tslib";
import { Component, Injectable, Input, ViewChild } from '@angular/core';
import { environment } from 'src/environments/environment';
import { LoaderEnabled } from '../loader/loader.service';
let ReportService = class ReportService {
    constructor(http) {
        this.http = http;
    }
    Report(type, tab, idaccountuser, filter) {
        return this.http.get(environment.SERVER + "custom/chartdata", { headers: { "Content-Type": "application/json" }, params: { type, tab, idaccountuser } });
    }
};
__decorate([
    LoaderEnabled()
], ReportService.prototype, "Report", null);
ReportService = __decorate([
    Injectable()
], ReportService);
export { ReportService };
let ReportComponent = class ReportComponent {
    constructor(report) {
        this.report = report;
        this.zoom = false;
        this.reportstatus = false;
        this.circularOption = {
            series: [],
            chart: {
                height: 200,
                type: "pie"
            },
            dataLabels: {
                enabled: true
            },
            labels: [],
            responsive: [
                {
                    breakpoint: 480,
                    options: {
                        chart: {
                            height: 200
                        }
                    }
                }
            ],
            legend: { show: false, horizontalAlign: 'top', showForSingleSeries: false },
        };
        this.lineOptions = {
            series: [
                {
                    name: "basic",
                    data: []
                }
            ],
            chart: {
                type: "bar",
                height: 200
            },
            plotOptions: {
                bar: {
                    horizontal: false
                }
            },
            dataLabels: {
                enabled: true
            },
            xaxis: {
                categories: []
            }
        };
    }
    OnDataChange(event) {
        if (this.graph == "bar" || this.graph == "area" || this.graph == "line") {
            this.getLineReport();
        }
        if (this.graph == "donut" || this.graph == "pie" || this.graph == "radialBar") {
            this.getCirularReport();
        }
    }
    getLineReport() {
        this.sub = this.report.Report(this.type, this.tab, this.idaccountuser).subscribe(res => {
            let xaxis = [];
            let fields = [];
            let label = [];
            let i = 0;
            res.reports.forEach((element, index) => {
                Object.entries(element).forEach((key, value) => {
                    if (key[0].toString() != "_id") {
                        if (key[0].toString() == "Date" || key[0].toString() == "Hour") {
                            xaxis.push(key[1]);
                        }
                        else {
                            if (index == 0) {
                                fields[key[0]] = [];
                                label.push(key[0]);
                                i++;
                            }
                            fields[key[0]].push(Math.round(parseFloat(key[1].toString()) * 100) / 100);
                        }
                    }
                });
            });
            this.lineOptions["xaxis"]["categories"] = xaxis;
            let data = [];
            label.forEach(ele => {
                data.push({ data: fields[ele], name: ele });
            });
            this.lineOptions["series"] = data;
            this.lineOptions["chart"]["type"] = this.graph;
            this.reportstatus = true;
        });
    }
    getCirularReport() {
        this.sub = this.report.Report(this.type, this.tab, this.idaccountuser).subscribe(res => {
            let tmpseries = [], tmplabels = [];
            if (res.reports.length == 1) {
                Object.entries(res.reports[0]).forEach((key) => {
                    if (key[0] !== "_id" && key[1] !== null) {
                        tmpseries.push(Math.round(parseFloat(key[1].toString()) * 100) / 100);
                        tmplabels.push(key[0]);
                    }
                });
                this.circularOption["series"] = tmpseries;
                this.circularOption["labels"] = tmplabels;
            }
            this.reportstatus = true;
        });
    }
    ngOnInit() {
        if (this.graph == "bar" || this.graph == "area" || this.graph == "line") {
            this.getLineReport();
        }
        if (this.graph == "donut" || this.graph == "pie" || this.graph == "radialBar") {
            this.getCirularReport();
        }
    }
    ngOnChanges() {
        this.ngOnInit();
    }
    // ngAfterViewInit() {
    // 	if (this.graph == "bar" || this.graph == "area" || this.graph == "line") {
    // 		this.getLineReport();
    // 	}
    // 	if (this.graph == "donut" || this.graph == "pie" || this.graph == "radialBar") {
    // 		this.getCirularReport();				
    // 	}
    // }
    ngOnDestroy() {
        if (this.sub != undefined)
            this.sub.unsubscribe();
    }
};
__decorate([
    Input()
], ReportComponent.prototype, "title", void 0);
__decorate([
    Input()
], ReportComponent.prototype, "type", void 0);
__decorate([
    Input()
], ReportComponent.prototype, "tab", void 0);
__decorate([
    Input()
], ReportComponent.prototype, "graph", void 0);
__decorate([
    Input()
], ReportComponent.prototype, "idaccountuser", void 0);
__decorate([
    Input()
], ReportComponent.prototype, "zoom", void 0);
__decorate([
    ViewChild("chart")
], ReportComponent.prototype, "chart", void 0);
ReportComponent = __decorate([
    Component({
        selector: 'Report',
        templateUrl: './report.component.html',
        styleUrls: ['./report.component.css']
    })
], ReportComponent);
export { ReportComponent };
//# sourceMappingURL=report.component.js.map