import { __decorate } from "tslib";
import { Component } from '@angular/core';
import { FormControl, Validators } from '@angular/forms';
let FactorauthenticationComponent = class FactorauthenticationComponent {
    constructor(data, router, fb, route) {
        this.data = data;
        this.router = router;
        this.fb = fb;
        this.route = route;
        this.submitted = false;
        this.message = '';
        this.twofaTemplate = {};
        this.errMessage = '';
        this.responseMessage = '';
        this.route.paramMap.subscribe((params) => {
            this.id2faTemplate = params.get('id');
            this.originalId2faTemplate = this.id2faTemplate;
            if (this.id2faTemplate) {
                this.data.get2FATemplate(this.id2faTemplate).subscribe(res => {
                    if (res.status == 200) {
                        if (res.data.length > 0) {
                            this.twofaTemplate = res.data[0];
                            this.factorauthenticationForm.patchValue({
                                id2fa_template: this.twofaTemplate.id2fa_template,
                                otp_digit: this.twofaTemplate.otp_digit,
                                type: this.twofaTemplate.type,
                                body: this.twofaTemplate.body
                            });
                        }
                    }
                    else {
                        this.errMessage = res.message;
                        setTimeout(() => {
                            this.errMessage = "";
                        }, 5000);
                    }
                });
            }
        });
    }
    ngOnInit() {
        this.factorauthenticationForm = this.fb.group({
            id2fa_template: [''],
            type: [''],
            otp_digit: ['', [Validators.required, Validators.pattern(/^[4-8]*$/)]],
            body: ['', [Validators.required]],
            tmpType: new FormControl('sms')
        });
    }
    click4(event) {
        this.message = this.factorauthenticationForm.value.body + event.target.value;
        this.factorauthenticationForm.patchValue({
            body: this.message
        });
    }
    onSubmit() {
        this.submitted = true;
        if (this.factorauthenticationForm.invalid) {
            return false;
        }
        else if (this.factorauthenticationForm.value.id2fa_template) {
            this.data.update2FATemplate(this.factorauthenticationForm.value).subscribe(res => {
                if (res.status == 201) {
                    this.responseMessage = res.message;
                    this.router.navigateByUrl('/sms/factor-authentication-details');
                    setTimeout(() => {
                        this.responseMessage = "";
                    }, 5000);
                }
                else {
                    this.errMessage = res.message;
                    setTimeout(() => {
                        this.errMessage = "";
                    }, 5000);
                }
            });
        }
        else {
            this.data.twofaTemaplate(this.factorauthenticationForm.value).subscribe(response => {
                if (response.status == 201) {
                    this.responseMessage = response.message;
                    this.router.navigateByUrl('/sms/factor-authentication-details');
                    setTimeout(() => {
                        this.responseMessage = "";
                    }, 5000);
                }
                else {
                    this.errMessage = response.message;
                    setTimeout(() => {
                        this.errMessage = "";
                    }, 5000);
                }
            });
        }
    }
    reset() {
        this.factorauthenticationForm.reset({
            id2fa_template: this.originalId2faTemplate,
            tmpType: 'sms'
        });
        this.submitted = false;
    }
};
FactorauthenticationComponent = __decorate([
    Component({
        selector: 'app-factorauthentication',
        templateUrl: './factorauthentication.component.html',
        styleUrls: ['./factorauthentication.component.css']
    })
], FactorauthenticationComponent);
export { FactorauthenticationComponent };
//# sourceMappingURL=factorauthentication.component.js.map