import { __decorate } from "tslib";
import { Component } from '@angular/core';
import { FormControl, Validators } from '@angular/forms';
let OperatorMappingComponent = class OperatorMappingComponent {
    constructor(tariffService, fb) {
        this.tariffService = tariffService;
        this.fb = fb;
        this.page = 1;
        this.count = 0;
        this.tableSize = 50;
        this.tableSizes = [50, 100, 200];
        this.searchText = { count: 0 };
        this.closeDropdownSelection = true;
        this.strategy1 = {};
        this.strategy2 = {};
        this.strategy3 = {};
        this.strategyOptions1 = [];
        this.strategyOptions2 = [];
        this.strategyOptions3 = [];
        this.responseMessage = "";
        this.submitted = false;
        this.mapdata = [];
        this.operatorForm = this.fb.group({
            strategyOptions1: new FormControl(null, [Validators.required]),
            strategyOptions2: new FormControl(null, [Validators.required]),
            strategyOptions3: new FormControl(null, [Validators.required]),
        });
    }
    ngOnInit() {
        this.strategy1 = {
            singleSelection: true,
            idField: 'id',
            textField: 'name',
            itemsShowLimit: 3,
            allowSearchFilter: true,
            closeDropDownOnSelection: this.closeDropdownSelection
        };
        this.strategy2 = {
            singleSelection: true,
            idField: 'idlerg_operator',
            textField: 'category',
            itemsShowLimit: 3,
            allowSearchFilter: true,
            closeDropDownOnSelection: this.closeDropdownSelection
        };
        this.strategy3 = {
            singleSelection: false,
            idField: 'idlerg_operator',
            textField: 'operator',
            itemsShowLimit: 3,
            allowSearchFilter: true
        };
        this.tariffService.searchByOperator("").subscribe(res => {
            this.strategyOptions1 = res.data;
        }, err => {
            this.responseMessage = err.message;
            setTimeout(() => {
                this.responseMessage = "";
            }, 3000);
        });
        this.tariffService.categoryLergInfo().subscribe(res => {
            this.strategyOptions2 = res.data;
            $.getScript('./assets/table.js');
        }, err => {
            this.responseMessage = err.message;
            setTimeout(() => {
                this.responseMessage = "";
            }, 3000);
        });
        this.tariffService.getoperatormaping().subscribe(res => {
            this.mapdata = [];
            let tmp = res.data;
            tmp.forEach(ele => {
                this.mapdata.push(JSON.parse("{" + ele.name + "}"));
            });
        });
    }
    setMapping() {
        this.submitted = true;
        if (this.operatorForm.invalid) {
            return;
        }
        else {
            let data = { operator1: this.operatorForm.value.strategyOptions1[0], category: this.operatorForm.value.strategyOptions2, operator2: this.operatorForm.value.strategyOptions3 };
            this.tariffService.setOperatorMapping(data).subscribe(res => {
                this.responseMessage = res.message;
                setTimeout(() => {
                    this.responseMessage = "";
                }, 3000);
                this.ngOnInit();
            }, err => {
                this.responseMessage = err.message;
                setTimeout(() => {
                    this.responseMessage = "";
                }, 3000);
            });
        }
    }
    onItemSelect(item) {
        this.tariffService.operatorsLergInfo(item).subscribe(res => {
            this.strategyOptions3 = res.data;
        }, err => {
            this.responseMessage = err.message;
            setTimeout(() => {
                this.responseMessage = "";
            }, 3000);
        });
    }
    deleteMapping(idmapping) {
        if (confirm("Are you sure you want delete Mapping!")) {
            this.tariffService.deleteMapping(idmapping).subscribe(res => {
                if (res.status == 201) {
                    this.responseMessage = res.message;
                    setTimeout(() => {
                        this.responseMessage = "";
                    }, 3000);
                    this.ngOnInit();
                }
                else {
                    this.responseMessage = res.message;
                    setTimeout(() => {
                        this.responseMessage = "";
                    }, 3000);
                    this.ngOnInit();
                }
            }, err => {
                this.responseMessage = err.message;
                setTimeout(() => {
                    this.responseMessage = "";
                }, 3000);
            });
        }
        else {
            "Cancel";
        }
    }
    onReset() {
        this.submitted = false;
        this.operatorForm.reset();
    }
};
OperatorMappingComponent = __decorate([
    Component({
        selector: 'app-operator-mapping',
        templateUrl: './operator-mapping.component.html',
        styleUrls: ['./operator-mapping.component.css']
    })
], OperatorMappingComponent);
export { OperatorMappingComponent };
//# sourceMappingURL=operator-mapping.component.js.map