import { __decorate, __param } from "tslib";
import { Component, EventEmitter, Inject, Output } from '@angular/core';
import { MAT_DIALOG_DATA } from '@angular/material/dialog';
import { environment } from 'src/environments/environment';
let AddCardComponent = class AddCardComponent {
    constructor(dialogRef, data = {}, data1, router) {
        this.dialogRef = dialogRef;
        this.data = data;
        this.data1 = data1;
        this.router = router;
        this.addCardClicked = new EventEmitter();
        this.stripeCards = [];
        this.isCard = false;
        this.isLimitExceeded = false;
    }
    ngOnInit() {
        this.data1.get_addcard().subscribe((result) => {
            this.cardHeader = result[0].card_headers;
            this.cardAction = result[0].heading;
        });
        this.data1.stripeCards().subscribe(res => {
            if (res.status == 200) {
                if (res.data.length > 0) {
                    this.stripeCards = res.data;
                    console.log("this.stripeCards", this.stripeCards);
                    this.isCard = true;
                    if (this.stripeCards.length >= 5) {
                        this.isLimitExceeded = true;
                    }
                    else {
                        this.isLimitExceeded = false;
                    }
                }
            }
            else {
                this.errMessage = res.message;
                setTimeout(() => {
                    this.errMessage = "";
                }, 5000);
            }
        }, err => {
            this.errMessage = err.message;
            setTimeout(() => {
                this.errMessage = "";
            }, 5000);
        });
    }
    onClose() {
        this.dialogRef.close({ data: this.data, reload: false });
        window.location.reload();
    }
    closeComponent() {
        this.dialogRef.close('closed');
    }
    createCard(event) {
        const paymentHandler = window.StripeCheckout.configure({
            key: environment.PublicKey,
            locale: 'auto',
            token: (stripeToken) => {
                this.data1.createCard(stripeToken).subscribe(res => {
                    if (res.status == 201) {
                        this.responseMessage = res.message;
                        if (event == 'default') {
                            this.setDefaultCard(res.customer_id);
                        }
                        setTimeout(() => {
                            this.responseMessage = "";
                        }, 5000);
                        this.ngOnInit();
                    }
                    else {
                        this.errMessage = res.message;
                        setTimeout(() => {
                            this.errMessage = "";
                        }, 5000);
                    }
                    this.data1.sendUpdate(res.message);
                }, err => {
                    this.errMessage = err.message;
                    setTimeout(() => {
                        this.errMessage = "";
                    }, 5000);
                });
            }
        });
        paymentHandler.open({
            name: 'signalmash',
            description: `Enter card Details`,
            amount: 0 * 100,
            panelLabel: 'Add Card',
            shippingAddress: false,
            billingAddress: true,
        });
    }
    deleteCard(customer_id, status, index) {
        if (status == 'true' || status == true) {
            this.errMessage = "Default Card can not be delete!";
            this.addCardClicked.emit({ status: '502', message: this.errMessage });
            setTimeout(() => {
                this.errMessage = "";
            }, 5000);
        }
        else {
            if (confirm("Are You Sure")) {
                this.data1.deleteCard(customer_id).subscribe(res => {
                    if (res.status == 201) {
                        this.responseMessage = res.message;
                        setTimeout(() => {
                            this.responseMessage = "";
                        }, 5000);
                        this.stripeCards.splice(index, 1);
                        this.ngOnInit();
                    }
                    else {
                        this.errMessage = res.message;
                        setTimeout(() => {
                            this.errMessage = "";
                        }, 5000);
                    }
                    this.data1.sendUpdate(res.message);
                }, err => {
                    this.errMessage = err.message;
                    setTimeout(() => {
                        this.errMessage = "";
                    }, 5000);
                });
            }
            else {
                return;
            }
        }
    }
    setDefault(customer_id, card_pdf, idstripecard) {
        if (card_pdf && card_pdf !== null && card_pdf.includes('card_pdf')) {
            if (confirm("Are You Sure ?")) {
                this.data1.setDefaultCard(customer_id).subscribe(res => {
                    if (res.status == 201) {
                        this.responseMessage = res.message;
                        setTimeout(() => {
                            this.responseMessage = "";
                        }, 5000);
                        this.ngOnInit();
                    }
                    else {
                        this.errMessage = res.message;
                        setTimeout(() => {
                            this.errMessage = "";
                        }, 5000);
                    }
                    this.data1.sendUpdate(res.message);
                }, err => {
                    this.errMessage = err.message;
                    setTimeout(() => {
                        this.errMessage = "";
                    }, 5000);
                });
            }
            else {
                return;
            }
        }
        else {
            if (confirm("You Need To Authorized This Card")) {
                this.dialogRef.close({});
                this.router.navigate(['/user/invoice-card-auth/' + idstripecard]);
            }
            else {
                return;
            }
        }
    }
    setDefaultCard(customer_id) {
        this.data1.setDefaultCard(customer_id).subscribe(res => {
            if (res.status == 201) {
                this.responseMessage = res.message;
                setTimeout(() => {
                    this.responseMessage = "";
                }, 5000);
                this.ngOnInit();
            }
            else {
                this.errMessage = res.message;
                setTimeout(() => {
                    this.errMessage = "";
                }, 5000);
            }
        }, err => {
            this.errMessage = err.message;
            setTimeout(() => {
                this.errMessage = "";
            }, 5000);
        });
    }
};
__decorate([
    Output()
], AddCardComponent.prototype, "addCardClicked", void 0);
AddCardComponent = __decorate([
    Component({
        selector: 'app-add-card',
        templateUrl: './add-card.component.html',
        styleUrls: ['./add-card.component.css']
    }),
    __param(1, Inject(MAT_DIALOG_DATA))
], AddCardComponent);
export { AddCardComponent };
//# sourceMappingURL=add-card.component.js.map