import { __awaiter, __decorate, __param } from "tslib";
import { Component, EventEmitter, Inject, Output, ViewChild } from '@angular/core';
import { Validators } from '@angular/forms';
import { MAT_DIALOG_DATA } from '@angular/material/dialog';
import { BehaviorSubject } from 'rxjs';
import { environment } from 'src/environments/environment';
let BalanceComponent = class BalanceComponent {
    constructor(dialogRef, data = {}, billingAddress, router, fb, userService) {
        this.dialogRef = dialogRef;
        this.data = data;
        this.billingAddress = billingAddress;
        this.router = router;
        this.fb = fb;
        this.userService = userService;
        this.submitClicked = new EventEmitter();
        this.amount = 20;
        this.submitted = false;
        this.errMessage = "";
        this.stripeCards = [];
        this.isCards = false;
        this.valMessage$ = new BehaviorSubject('');
        this.valMessage = this.valMessage$.asObservable();
        this.isNewCard = false;
        this.checked = false;
        this.show = false;
        this.customerId = "";
        this.expireDefaultCard = false;
        this.notAuthorization = false;
    }
    ngOnInit() {
        this.address = this.data.address[0] || {};
        this.userProfile = this.data.userProfile[0] || {};
        this.billingAddressForm = this.fb.group({
            amount: [this.amount, [Validators.required,
                    //Validators.min(20),
                    Validators.max(500000),
                    Validators.pattern(/^\d*(?:[.,]\d{1,2})?$/),
                ]],
            customer_id: [''],
            first_name: [''],
            last_name: [''],
            contact: [''],
            email: [''],
            address1: [''],
            address2: [''],
            city: [''],
            state: [''],
            postal_code: [''],
            country: [''],
            currentDateTime: []
        });
        this.billingAddressForm.patchValue({
            amount: this.amount || 0,
            first_name: this.userProfile.first_name,
            last_name: this.userProfile.last_name,
            contact: this.userProfile.contact_number,
            email: this.userProfile.email,
            address1: this.address.address1,
            address2: this.address.address2,
            city: this.address.city,
            state: this.address.state,
            postal_code: this.address.postal_code,
            country: this.address.country,
        });
        this.userService.stripeCards().subscribe(res => {
            if (res.status == 200) {
                if (res.data.length > 0) {
                    this.stripeCards = res.data.filter((card) => card.isdeleted === 0);
                    this.stripeCards.forEach((element, index) => {
                        if (element.card_pdf == null || element.card_pdf == "null" || element.card_pdf == undefined || element.card_pdf == "undefined" || element.card_pdf == '' || !element.card_pdf.includes('card_pdf')) {
                            element.notAuthorization = false;
                        }
                        else {
                            element.notAuthorization = true;
                        }
                    });
                    this.isCards = true;
                    if (this.stripeCards.length >= 5) {
                        this.isNewCard = false;
                    }
                    else {
                        this.isNewCard = false;
                    }
                }
            }
            else {
                this.errMessage = res.message;
                setTimeout(() => {
                    this.errMessage = "";
                }, 5000);
            }
        });
        this.invokeStripe();
    }
    // getAmount(e) {
    //   this.amount = e.target.value;
    //   this.billingAddressForm.patchValue({
    //     amount: this.amount
    //   });
    // }
    authorizeCard(idstripecard) {
        this.router.navigate(['/user/invoice-card-auth/' + idstripecard]);
        this.closemodal.nativeElement.click();
    }
    getAmount(e) {
        this.expireDefaultCard = false;
        this.notAuthorization = false;
        this.billingAddressForm.patchValue({
            // amount: this.amount
            amount: e.target.value
        });
        let data = e.target.value;
        this.submitted = false;
        e.target.value = (data.indexOf(".") >= 0) ? (data.substr(0, data.indexOf(".")) + data.substr(data.indexOf("."), 3)) : data;
        return this.amount = e.target.value;
    }
    selectCard(customer_id) {
        this.expireDefaultCard = false;
        this.notAuthorization = false;
        this.stripeCards.find(res => {
            if (customer_id == res.customer_id) {
                this.billingAddressForm.patchValue({
                    customer_id: res.customer_id
                });
                this.customerId = res.customer_id;
            }
        });
    }
    addWithExisting() {
        let card;
        this.stripeCards.find(res => {
            if (res.customer_id == this.billingAddressForm.value.customer_id) {
                card = res.exp_month + '/' + res.exp_year + '**** ' + res.last4;
            }
        });
        if (this.billingAddressForm.value.customer_id) {
            if (confirm(`Please Confirm Card ${card}`)) {
                this.billingAddress.updateBalance(JSON.stringify({ pdata: this.billingAddressForm.value })).subscribe(response => {
                    if (response.status == 201) {
                        this.dialogRef.close({ message: response.message, reload: true });
                    }
                    else {
                        this.valMessage$.next(response.message);
                        setTimeout(() => {
                            this.valMessage$.next("");
                        }, 5000);
                    }
                });
            }
            else {
                return;
            }
        }
        else {
            this.valMessage$.next("Please Select Card");
            setTimeout(() => {
                this.valMessage$.next("");
            }, 5000);
        }
    }
    addAmount() {
        if (this.billingAddressForm.invalid) {
            this.submitted = true;
            // this.valMessage$.next("Invalid Amount or Account Profile");
            // setTimeout(() => {
            //   this.valMessage$.next("");
            // }, 5000);
        }
        else {
            this.billingAddressForm.patchValue({
                amount: this.amount,
                currentDateTime: this.current_datetime(),
            });
            // if(this.billingAddressForm.value.customer_id){
            //     this.addWithExisting();
            // }
            // else{
            if (this.billingAddressForm.value.customer_id) {
                this.billingAddressForm.patchValue({
                    customer_id: this.billingAddressForm.value.customer_id
                });
                this.openCheckout(this.billingAddressForm.value);
            }
            else {
                this.userService.stripeDefaultCards().subscribe(res => {
                    if (res.status == 200) {
                        this.stripeDefaultCards = res.data[0];
                        this.isCards = true;
                        this.customerId = this.stripeDefaultCards.customer_id;
                        this.billingAddressForm.patchValue({
                            customer_id: this.stripeDefaultCards.customer_id
                        });
                        this.openCheckout(this.billingAddressForm.value);
                    }
                    else {
                        this.openCheckout(this.billingAddressForm.value);
                    }
                });
            }
            // }
        }
    }
    openCheckout(billingData) {
        return __awaiter(this, void 0, void 0, function* () {
            if (billingData.customer_id != '' && billingData.customer_id) {
                let response = yield this.checkExpiryCard();
                if (response.status == 201) {
                    yield this.billingAddress.updateBalance(JSON.stringify({ pdata: billingData })).subscribe(response => {
                        if (response.status == 201) {
                            this.dialogRef.close({ message: response.message, reload: true });
                        }
                        else {
                            this.valMessage$.next(response.message);
                            setTimeout(() => {
                                this.valMessage$.next("");
                            }, 5000);
                        }
                    });
                }
                else {
                    return;
                }
            }
            else {
                const paymentHandler = window.StripeCheckout.configure({
                    key: environment.PublicKey,
                    locale: 'auto',
                    token: (stripeToken) => {
                        this.billingAddress.addBalance(JSON.stringify({ pdata: billingData, token: stripeToken })).subscribe(response => {
                            if (response.status == 201) {
                                alert("We are adding this card as a Default Card!");
                                this.dialogRef.close({ message: response.message, reload: true });
                            }
                            else {
                                this.errMessage = response.message;
                                setTimeout(() => {
                                    this.errMessage = "";
                                }, 5000);
                            }
                        });
                    }
                });
                paymentHandler.open({
                    name: 'Signalmash Admin',
                    // description: `Amount ${this.amount} Added For Your Signalmash Wallet`,
                    amount: this.amount * 100,
                    shippingAddress: false,
                    billingAddress: true,
                });
            }
        });
    }
    checkExpiryCard() {
        return new Promise((resolve, reject) => {
            let now = new Date();
            let year = Number("" + now.getFullYear());
            let month = Number("" + (now.getMonth() + 1));
            if (month.length == 1) {
                month = "0" + month;
            }
            this.stripeCards.forEach((element, index) => {
                if (element.customer_id == this.customerId) {
                    let DefaultCardMonth = Number(element.exp_month);
                    let DefaultCardYear = Number(element.exp_year);
                    if ((DefaultCardMonth < month && DefaultCardYear < year) || (DefaultCardYear == year && DefaultCardMonth < month) || (DefaultCardMonth > month && DefaultCardYear < year) || (DefaultCardMonth == month && DefaultCardYear < year)) {
                        this.expireDefaultCard = true;
                        this.errMessage = "Your Card Is Expired Please Change Your Card";
                        this.submitClicked.emit(this.errMessage);
                    }
                    if (element.card_pdf == null || element.card_pdf == "null" || element.card_pdf == undefined || element.card_pdf == "undefined" || element.card_pdf == '' || !element.card_pdf.includes('card_pdf')) {
                        this.notAuthorization = true;
                        this.errMessage = "Your Card Is Not Authorized  Please Change Your Card";
                        this.submitClicked.emit(this.errMessage);
                    }
                }
                if (this.stripeCards.length - 1 == index) {
                    if (this.notAuthorization == true || this.expireDefaultCard == true) {
                        resolve({ status: 502 });
                    }
                    else {
                        resolve({ status: 201 });
                    }
                }
            });
            setTimeout(() => {
                this.errMessage = "";
            }, 5000);
        });
    }
    invokeStripe() {
        if (!window.document.getElementById('stripe-script')) {
            const script = window.document.createElement("script");
            script.id = "stripe-script";
            script.type = "text/javascript";
            script.src = "https://checkout.stripe.com/checkout.js";
            script.onload = () => {
                this.paymentHandler = window.StripeCheckout.configure({
                    key: environment.PublicKey,
                    locale: 'auto',
                    token: (stripeToken) => {
                        alert('Payment has been successfully!');
                    }
                });
            };
            window.document.body.appendChild(script);
        }
    }
    current_datetime() {
        let now = new Date();
        let year = "" + now.getFullYear();
        let month = "" + (now.getMonth() + 1);
        if (month.length == 1) {
            month = "0" + month;
        }
        let day = "" + now.getDate();
        if (day.length == 1) {
            day = "0" + day;
        }
        let hour = "" + now.getHours();
        if (hour.length == 1) {
            hour = "0" + hour;
        }
        let minute = "" + now.getMinutes();
        if (minute.length == 1) {
            minute = "0" + minute;
        }
        let second = "" + now.getSeconds();
        if (second.length == 1) {
            second = "0" + second;
        }
        return year + "-" + month + "-" + day + " " + hour + ":" + minute + ":" + second;
    }
    onClose() {
        this.dialogRef.close({ data: this.data, reload: false });
    }
};
__decorate([
    ViewChild('closemodal')
], BalanceComponent.prototype, "closemodal", void 0);
__decorate([
    Output()
], BalanceComponent.prototype, "submitClicked", void 0);
BalanceComponent = __decorate([
    Component({
        selector: 'app-balance',
        templateUrl: './balance.component.html',
        styleUrls: ['./balance.component.css']
    }),
    __param(1, Inject(MAT_DIALOG_DATA))
], BalanceComponent);
export { BalanceComponent };
//# sourceMappingURL=balance.component.js.map